==> simLifeCore-0.0.2-sources.jar: barsuift/simLife/tree/BasicTreeBranchFactory.java <==
/**
 * barsuift-simlife is a life simulator programm
 * 
 * Copyright (C) 2010 Cyrille GACHOT
 * 
 * This file is part of barsuift-simlife.
 * 
 * barsuift-simlife is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
 * version.
 * 
 * barsuift-simlife is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with barsuift-simlife. If not, see
 * <http://www.gnu.org/licenses/>.
 */
package barsuift.simLife.tree;

import javax.vecmath.Point3d;
import javax.vecmath.Vector3d;

import barsuift.simLife.universe.Universe;

public class BasicTreeBranchFactory {

    private final Universe universe;

    public BasicTreeBranchFactory(Universe universe) {
        this.universe = universe;
    }

    public TreeBranch createRandom(Vector3d translationVector, Point3d branchEndPoint) {
        TreeBranchStateFactory treeBranchStateFactory = new TreeBranchStateFactory();
        TreeBranchState treeBranchState = treeBranchStateFactory.createRandomBranchState(translationVector, branchEndPoint);
        TreeBranch treeBranch = new BasicTreeBranch(universe, treeBranchState);
        return treeBranch;
    }


}

==> simLifeCore-0.0.4-sources.jar: barsuift/simLife/tree/BasicTreeBranchFactory.java <==
/**
 * barsuift-simlife is a life simulator program
 * 
 * Copyright (C) 2010 Cyrille GACHOT
 * 
 * This file is part of barsuift-simlife.
 * 
 * barsuift-simlife is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
 * version.
 * 
 * barsuift-simlife is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with barsuift-simlife. If not, see
 * <http://www.gnu.org/licenses/>.
 */
package barsuift.simLife.tree;

import javax.vecmath.Point3d;
import javax.vecmath.Vector3d;

import barsuift.simLife.universe.Universe;

public class BasicTreeBranchFactory {

    private final Universe universe;

    public BasicTreeBranchFactory(Universe universe) {
        this.universe = universe;
    }

    public TreeBranch createRandom(Vector3d translationVector, Point3d branchEndPoint) {
        TreeBranchStateFactory treeBranchStateFactory = new TreeBranchStateFactory();
        TreeBranchState treeBranchState = treeBranchStateFactory.createRandomBranchState(translationVector,
                branchEndPoint);
        TreeBranch treeBranch = new BasicTreeBranch(universe, treeBranchState);
        return treeBranch;
    }


}
